########## Regression analysis Oil consumption and GDP
library(strucchange)
library(tseries)
library(ggplot2)
library(nlme)

## Dataset
dataset3 <- read.csv("~/Desktop/Papier 0 -Review answer/Regression papier 0/data.csv", sep=";", dec=",")
dataset3 <- na.remove(dataset3)
oil.world <- ts(dataset3[,2], frequency=1, start=c(1965,1))
GNI <- ts(dataset3[,3], frequency=1, start=c(1965,1))

#plot(oil.world)
#plot(GNI)

#### Log data for elasticity
oil.world.log = log(oil.world)
#plot(oil.world.log)
GNI.log <- log(GNI)
#plot(GNI.log)
#plot(oil.world.log~GNI.log, type='l')

####### Structural break
oil.nile <-  Fstats(oil.world.log~GNI.log)
plot(oil.nile)
breakpoints(oil.nile)
lines(breakpoints(oil.nile))


#Breakpoints Bay Perron (2003)
bp.nile <- breakpoints(oil.world.log~GNI.log, breaks=1)
summary(bp.nile)
## the BIC also chooses one breakpoint
plot(bp.nile)
breakpoints(bp.nile)
## fit null hypothesis model and model with 1 breakpoint
fm0 <- lm(oil.world.log~GNI.log)
fm1 <- lm(oil.world.log ~ breakfactor(bp.nile, breaks = 1)/(GNI.log)-1)
summary(fm0)
summary(fm1)


## Sub-period regression
fm1.1 <- lm(window(oil.world.log, end=c(1979,1))~window(GNI.log, end=c(1979,1)))
fm1.2 <- lm(window(oil.world.log, start=c(1980,1))~window(GNI.log, start=c(1980,1)))
summary(fm1.1)
summary(fm1.2)

lafit <- ts(fitted(fm1), frequency=1, start = c(1965,1))

####### Plot 

RatioooO <- data.frame(oil=oil.world.log,GNI=GNI.log, filted = lafit)
bplot4 <- ggplot(RatioooO, aes(x=GNI, y=oil, z=filted)) +
  theme_bw() + geom_line(aes(y=filted), size=0.7, col="red", linetype=2) + #geom_point(aes(y = oil), colour="red", size=2) +
  geom_line(aes(y=oil), size=0.5, linetype=3) + xlab("log of real GNI") + ylab("log of oil consumption") + 
  ggtitle("Productivity of oil, world, 1965-2013");
plot(bplot4)
#Add line at structural break, 30.71849 is the value of GNI.log en 1979
bplot4 + geom_vline(xintercept = 30.71849 ,linetype = "longdash");

